@@ -3,9 +3,11 @@ youtube-search-requests
 
 Search youtube videos using requests without Youtube API.
 """
+import sys
+
 from youtube_search_requests.search import YoutubeSearch
 from youtube_search_requests.session import YoutubeSession
 from youtube_search_requests.async_session import AsyncYoutubeSession
 from youtube_search_requests.async_search import AsyncYoutubeSearch
 
-__VERSION__ = 'v0.0.24.2'
\ No newline at end of file
+__VERSION__ = 'v0.0.25'
\ No newline at end of file
