@@ -1,19 +1,58 @@
 # youtube-search-requests 
 # utils.__init__.py
 import json
+import sys
 import requests
 from youtube_search_requests.utils.errors import InvalidURL
 
-def parse_json_session_data(r: requests.Request):
+class YoutubePreferenceCookie:
+    def __init__(self):
+        self.cookie = {'PREF': {}}
+
+    def _parse_preference(self, p: str):
+        if '&' in p:
+            pref = {}
+            for i in p.split('&'):
+                a = i.split('=')
+                pref[a[0]] = a[1]
+            return pref
+        else:
+            indexes = p.split('=')
+            return indexes[0], indexes[1]
+
+    def add_preference(self, preference: str):
+        PREF = self._parse_preference(preference)
+        if isinstance(PREF, dict):
+            for key in PREF.keys():
+                self.cookie['PREF'][key] = PREF[key]
+        else:
+            self.cookie['PREF'][PREF[0]] = PREF[1]
+
+    def get_cookie(self):
+        PREF = self.cookie['PREF']
+        a = ''
+        if len(PREF.keys()) == 1:
+            for key in PREF.keys():
+                a += key + '=' + PREF[key]
+        elif len(PREF.keys()) == 0:
+            return {}
+        else:
+            for key in PREF.keys():
+                a += key + '=' + PREF[key] + '&'
+        return {'PREF': a}
+
+        
+
+def parse_json_session_data(r):
     d = r.text[r.text.find('ytcfg.set({') + 10:]
     return json.loads(d[0:d.find(');')])
 
-async def parse_json_async_session_data(s: str):
+async def parse_json_async_session_data(s):
     d = s[s.find('ytcfg.set({') + 10:]
     return json.loads(d[0:d.find(');')])
 
 class SearchRelatedVideos:
-    def __init__(self, url: str):
+    def __init__(self, url):
         if 'https://www.youtube.com/watch?v=' in url:
             pass
         elif 'https://youtu.be/' in url:
@@ -26,13 +65,13 @@ class SearchRelatedVideos:
             'videoRenderer'
         ]
 
-    def _wrap_dict_related_videos(self, data: str):
+    def _wrap_dict_related_videos(self, data):
         startpos = data.find('var ytInitialData = ')
         text2 = data[startpos+20:]
         endpos = text2.find('"}};</script>') + 3
         return json.loads(text2[:endpos])
 
-    def _get_info(self, data: dict, info: str):
+    def _get_info(self, data, info):
         try:
             d = data[info]
         except KeyError:
@@ -58,11 +97,11 @@ class SearchRelatedVideos:
     def _get_thumbnails(self, data):
         return data['thumbnail']['thumbnails']
 
-    def _request_search(self, url: str):
+    def _request_search(self, url):
         r = requests.get(url)
         return r.text
 
-    def _get_related_videos(self, data: dict):
+    def _get_related_videos(self, data):
         d = data['contents']['twoColumnWatchNextResults']['secondaryResults']['secondaryResults']['results']
         videos = []
         v = None
@@ -101,7 +140,7 @@ class SearchRelatedVideos:
             return None
 
 class GetVideosData:
-    def __init__(self, dict_data: dict, include_related_videos=False, use_short_link=False):
+    def __init__(self, dict_data, include_related_videos=False, use_short_link=False):
         self.data = dict_data
         self.include_related_videos = include_related_videos
         self.use_short_link = use_short_link
@@ -165,14 +204,14 @@ class GetVideosData:
                 return t1
         return None
 
-    def get_related_videos(self, url: str):
+    def get_related_videos(self, url):
         if self.include_related_videos:
             s = SearchRelatedVideos(url)
             return s.get_related_videos()
         else:
             return None
 
-    def _get_info(self, data: dict, info: str):
+    def _get_info(self, data, info):
         try:
             d = data[info]
         except KeyError:
@@ -232,7 +271,7 @@ class GetVideosData:
 
 
 class GetContinuationToken:
-    def __init__(self, dict_data: dict):
+    def __init__(self, dict_data):
         self.data = dict_data
         self._PARSE_METHODS = [
             self._parse_method1,
